# Generated by Django 4.1.7 on 2023-05-29 11:49

import uuid

import django.contrib.postgres.fields
import django.core.validators
import django.db.models.deletion
import enumfields.fields
from django.db import migrations, models

import arkindex.project.aws
import arkindex.project.fields
import arkindex.training.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("process", "0001_initial"),
        ("documents", "0002_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Dataset",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=100, validators=[django.core.validators.MinLengthValidator(1)])),
                ("description", models.TextField(validators=[django.core.validators.MinLengthValidator(1)])),
                ("state", enumfields.fields.EnumField(default="open", enum=arkindex.training.models.DatasetState, max_length=10)),
                ("sets", django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=50, validators=[django.core.validators.MinLengthValidator(1)]), default=arkindex.training.models.default_sets, size=None, validators=[django.core.validators.MinLengthValidator(1), arkindex.training.models.validate_unique_set_names])),
                ("corpus", models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name="datasets", to="documents.corpus")),
            ],
        ),
        migrations.CreateModel(
            name="MetricKey",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=100)),
                ("mode", enumfields.fields.EnumField(default="series", enum=arkindex.training.models.MetricMode, max_length=10)),
            ],
        ),
        migrations.CreateModel(
            name="Model",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=100, unique=True)),
                ("description", models.TextField(default="", blank=True)),
                ("public", models.BooleanField(default=False)),
                ("compatible_workers", models.ManyToManyField(related_name="models", to="process.worker", blank=True)),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="ModelVersion",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("updated", models.DateTimeField(auto_now=True)),
                ("description", models.TextField(default="")),
                ("tag", models.CharField(default=None, max_length=50, null=True)),
                ("state", enumfields.fields.EnumField(default="created", enum=arkindex.training.models.ModelVersionState, max_length=10)),
                ("hash", arkindex.project.fields.MD5HashField(blank=True, help_text="hash of the content of the archive which contains the model version's data", max_length=32, null=True)),
                ("archive_hash", arkindex.project.fields.MD5HashField(blank=True, help_text="hash of the archive which contains the model version's data", max_length=32, null=True)),
                ("size", models.PositiveIntegerField(blank=True, help_text="file size in bytes", null=True)),
                ("configuration", models.JSONField(default=dict)),
                ("model", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="versions", to="training.model")),
                ("parent", models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name="children", to="training.modelversion")),
            ],
            bases=(arkindex.project.aws.S3FileMixin, models.Model),
        ),
        migrations.CreateModel(
            name="MetricValue",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("value", models.FloatField()),
                ("created", models.DateTimeField(auto_now_add=True)),
                ("step", models.PositiveIntegerField(blank=True, null=True)),
                ("metric", models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="values", to="training.metrickey")),
            ],
        ),
        migrations.AddField(
            model_name="metrickey",
            name="model_version",
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="metrics", to="training.modelversion"),
        ),
        migrations.CreateModel(
            name="DatasetElement",
            fields=[
                ("id", models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ("set", models.CharField(max_length=50, validators=[django.core.validators.MinLengthValidator(1)])),
                ("dataset", models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name="dataset_elements", to="training.dataset")),
                ("element", models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name="dataset_elements", to="documents.element")),
            ],
        ),
    ]
